const path = require('path');
const webpack = require('webpack');

// we pick up package.json for the *package we want do build*
const packageDir = path.resolve('.')
const packageJSON = require(path.join(packageDir,'package.json'))

console.log('Building bundle with SDK + React for package in',packageDir)

// make sure we define NODE_ENV, used by React
const nodeEnvPlugin = new webpack.DefinePlugin({
  'process.env.NODE_ENV': JSON.stringify('production')
})

module.exports = {
  entry: [ "./node_modules/core-js/es6/map.js", "./node_modules/core-js/es6/set.js", "./bundles/browser-bundle-with-sdk.js" ],
  output: {
      publicPath: 'dist/',
      path: path.join(packageDir,'dist'),
      filename: packageJSON.name+'-with-sdk-and-react.min.js'
  },
  module: {
    rules: [
      {
        test: [/\.js$/,/\.jsx$/],
        include: [
          path.join(packageDir, 'bundles'),
          path.join(packageDir, 'src')],
        loader: 'babel-loader',
        options: {
          presets: ["es2015","react"],
          plugins: [
            ['transform-css-require'],
            ['transform-object-rest-spread'],
            ['transform-class-properties'],
            ['transform-object-assign']]
        }
      }
    ]
  },
  // react is included in the standalone bundles
  resolve: {
    extensions: ['.js', '.jsx']
  },
  devtool: 'source-map',
  plugins: [nodeEnvPlugin]
};
